Pulse width modulate a pin using the MultiTech mDot.

Dependencies:   mbed

Fork of Dragonfly_PwmOut_Example by MultiTech

Files at this revision

API Documentation at this revision

Comitter:
mfiore
Date:
Fri Oct 02 16:42:59 2015 +0000
Parent:
0:4a3a5f1bdca6
Commit message:
update for mDot

Changed in this revision

main.cpp Show annotated file Show diff for this revision Revisions of this file
diff -r 4a3a5f1bdca6 -r 8c4800b7cfc7 main.cpp
--- a/main.cpp	Fri Oct 02 14:00:17 2015 +0000
+++ b/main.cpp	Fri Oct 02 16:42:59 2015 +0000
@@ -1,17 +1,17 @@
-/** Dragonfly PwmOut Example Program
+/** mDot PwmOut Example Program
  *
  * This program demonstrates how to do pulse width modulation on
- * and output pin using the MultiTech Dragonfly and MultiTech UDK2
+ * and output pin using the MultiTech mDot and MultiTech UDK2
  * hardware. The only additional hardware required is a LED.
  *
  * This program PWMs the D12 pin. It should go from 0% to 100% duty
  * cycle in 5% increments and then from 100% to 0% in 5% increments.
  */
  
 #include "mbed.h"
  
 int main() {
-    PwmOut out(D12);
+    PwmOut out(XBEE_DO8);
     
     while (true) {
         for (float f = 0.0f; f < 1.0f; f += 0.05f) {
@@ -1,17 +1,17 @@
  * hardware. The only additional hardware required is a LED.
  *
- * This program PWMs the D12 pin. It should go from 0% to 100% duty
+ * This program PWMs the XBEE_DO8 (UDK2 D12) pin. It should go from 0% to 100% duty
  * cycle in 5% increments and then from 100% to 0% in 5% increments.
  */